From 311999fbc70cdb51163fa36d8ffc2f3ece7bf307 Mon Sep 17 00:00:00 2001
From: Nico <32375741+nulmete@users.noreply.github.com>
Date: Mon, 23 Feb 2026 17:18:43 -0300
Subject: [PATCH] Migrate some 'Query' occurrences to 'Report' (#40320)
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
Observed some places where we still show Query instead of Report:
# Checklist for submitter
- [ ] Changes file added for user-visible changes in `changes/`,
`orbit/changes/` or `ee/fleetd-chrome/changes`.
See [Changes
files](https://github.com/fleetdm/fleet/blob/main/docs/Contributing/guides/committing-changes.md#changes-files)
for more information.
## Testing
- [x] Added/updated automated tests
- [x] QA'd all new/changed functionality manually
---
.../LiveResults/LiveResultsHeading/LiveResultsHeading.tsx | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/frontend/components/queries/LiveResults/LiveResultsHeading/LiveResultsHeading.tsx b/frontend/components/queries/LiveResults/LiveResultsHeading/LiveResultsHeading.tsx
index 605367eec3..bf576613bf 100644
--- a/frontend/components/queries/LiveResults/LiveResultsHeading/LiveResultsHeading.tsx
+++ b/frontend/components/queries/LiveResults/LiveResultsHeading/LiveResultsHeading.tsx
@@ -61,8 +61,8 @@ interface ILiveResultsHeadingProps {
onClickDone: (evt: React.MouseEvent) => void;
onClickRunAgain: (evt: React.MouseEvent) => void;
onClickStop: (evt: React.MouseEvent) => void;
- /** Whether this is a live run of a policy or a query */
- resultsType?: "query" | "policy";
+ /** Whether this is a live run of a policy or a report */
+ resultsType?: "report" | "policy";
}
const LiveResultsHeading = ({
@@ -75,7 +75,7 @@ const LiveResultsHeading = ({
onClickDone,
onClickRunAgain,
onClickStop,
- resultsType = "query",
+ resultsType = "report",
}: ILiveResultsHeadingProps) => {
const percentResponded =
numHostsTargeted > 0